@@ -1,6 +1,6 @@
 /*
  *	aegis - a project change supervisor
- *	Copyright (C) 1994, 1996, 1997 Peter Miller;
+ *	Copyright (C) 1994, 1996, 1997, 2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -38,9 +38,16 @@
 #endif
 #endif
 
-#ifdef HAVE_UNISTD_H
-#include <sys/types.h>
+#if HAVE_UNISTD_H
+#include <ac/sys/types.h>
 #include <unistd.h>
 #endif
 
+#ifndef CONF_NO_seteuid
+#ifndef HAVE_SETEUID
+int seteuid(int);
+int setegid(int);
+#endif
+#endif
+
 #endif /* COMMON_AC_UNISTD_H */
