@@ -1,28 +1,33 @@
-/*
- *	aegis - project change supervisor
- *	Copyright (C) 1991-1995, 1998, 1999, 2001, 2002 Peter Miller;
- *	All rights reserved.
- *
- *	This program is free software; you can redistribute it and/or modify
- *	it under the terms of the GNU General Public License as published by
- *	the Free Software Foundation; either version 2 of the License, or
- *	(at your option) any later version.
- *
- *	This program is distributed in the hope that it will be useful,
- *	but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	GNU General Public License for more details.
- *
- *	You should have received a copy of the GNU General Public License
- *	along with this program; if not, write to the Free Software
- *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
- *
- * MANIFEST: interface definition for common/str.c
- */
+//
+//	aegis - project change supervisor
+//	Copyright (C) 1991-1995, 1998, 1999, 2001-2004 Peter Miller;
+//	All rights reserved.
+//
+//	This program is free software; you can redistribute it and/or modify
+//	it under the terms of the GNU General Public License as published by
+//	the Free Software Foundation; either version 2 of the License, or
+//	(at your option) any later version.
+//
+//	This program is distributed in the hope that it will be useful,
+//	but WITHOUT ANY WARRANTY; without even the implied warranty of
+//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//	GNU General Public License for more details.
+//
+//	You should have received a copy of the GNU General Public License
+//	along with this program; if not, write to the Free Software
+//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+//
+// MANIFEST: interface definition for common/str.c
+//
 
 #ifndef STR_H
 #define STR_H
 
+/** \addtogroup String
+  * \brief String manipulation funtions
+  * \ingroup Common
+  * @{
+  */
 #include <ac/stddef.h>
 #include <ac/stdarg.h>
 #include <main.h>
@@ -47,7 +52,6 @@ typedef unsigned long str_hash_ty;
   * <b>Thou shalt not</b> modify any member of a string struct, or the
   * forces of evil shall wreak misery in thy life.
   */
-typedef struct string_ty string_ty;
 struct string_ty
 {
     /**
@@ -85,20 +89,6 @@ struct string_ty
     char	    str_text[1];
 };
 
-/**
-  * \brief
-  *	start up string table
-  *
-  * The str_initialize function is used to create the hash table and
-  * initialize it to empty.
-  *
-  * This function must be called before any other defined in this file.
-  *
-  * \return
-  *	void
-  */
-void str_initialize(void);
-
 /**
   * \brief
   *	make string from C string
@@ -330,7 +320,7 @@ string_ty *str_field(string_ty *str, int sep, int nth);
   * \return
   *	void
   */
-void slow_to_fast(char **, string_ty **, size_t);
+void slow_to_fast(const char *const *, string_ty **, size_t);
 
 /**
   * \brief
@@ -351,7 +341,7 @@ void slow_to_fast(char **, string_ty **, size_t);
   *	finished with.	The contents of the structure pointed to <b>shall
   *	not</b> be altered.
   */
-string_ty *str_format(const char *fmt, ...);
+string_ty *str_format(const char *fmt, ...)               ATTR_PRINTF(1, 2);
 
 /**
   * \brief
@@ -410,64 +400,6 @@ int str_equal(string_ty *str1, string_ty *str2);
   */
 #define str_equal(s1, s2) ((s1) == (s2))
 
-/**
-  * \brief
-  *	regular expression match
-  *
-  * The str_re_match function is used to test for a regular expression
-  * match.
-  *
-  * \param pattern
-  *	The regular expression pattern to be matched against (excluding
-  *	the slashes).  Will not be modified.
-  * \param candidate
-  *	The string to be tested, to see if it matches the \a pattern.
-  *	Will not be modified.
-  * \param callback
-  *	A pointer to an error message function to be called if there is
-  *	something wrong with the pattern.  If this pointer is NULL,
-  *	it will not be called.
-  *
-  * \return
-  *	Positive if there is a match, zero if there is not,
-  *	negative if an error occurred (usually, a broken \a pattern string).
-  */
-int str_re_match(string_ty *pattern, string_ty *candidate,
-    void (*callback)(const char *));
-
-/**
-  * \brief
-  *	regular expression substitute
-  *
-  * The str_re_substitute function is used to performa a regular
-  * expression match of the \a actual string against the \a lhs (the
-  * pattern) and then substitute into the \a rhs string.
-  *
-  * \param lhs
-  *	The left hand side (the regular expression).
-  *	Will not be modified.
-  * \param rhs
-  *	The right hand side (the replacement).
-  *	Will not be modified.
-  * \param actual
-  *	The string to be matched and replaced.	Will not be modified
-  *	(the operation is <b>not</b> performed <i>in situ</i>).
-  * \param callback
-  *	A pointer to an error message function to be called if there is
-  *	something wrong with the pattern.  If this pointer is NULL,
-  *	it will not be called.
-  * \param count
-  *	The maximum number of times to match the expression agains the
-  *	string (zero means infinite).
-  *
-  * \return
-  *	a pointer to a string in dynamic memory.  Use str_free() when
-  *	finished with.	The contents of the structure pointed to <b>shall
-  *	not</b> be altered.  Returns NULL if there was an error.
-  */
-string_ty *str_re_substitute(string_ty *lhs, string_ty *rhs, string_ty *actual,
-    void (*callback)(const char *), int count_);
-
 /**
   * \brief
   *	quote shell meta-characters
@@ -519,7 +451,7 @@ string_ty *str_trim(string_ty *str);
   * \return
   *	Non-zero if valid, zero if invalid.
   */
-int str_validate(string_ty *);
+int str_validate(const string_ty *str);
 
 /**
   * \brief
@@ -534,8 +466,60 @@ int str_validate(string_ty *);
   *	The substring to be tested for.
   *
   * \return
-  *	Non-zero if is a leadinf prefix, zero if not.
+  *	Non-zero if is a leading prefix, zero if not.
   */
 int str_leading_prefix(string_ty *haystack, string_ty *needle);
 
-#endif /* STR_H */
+/**
+  * \brief
+  *	look for a trailing suffix
+  *
+  * The str_trailing_suffix function is used to test whether the \a needle
+  * argument is a trailing suffix of the \a haystack argument.
+  *
+  * \param haystack
+  *	The large string which allegedly contains the \a needle.
+  * \param needle
+  *	The substring to be tested for.
+  *
+  * \return
+  *	Non-zero if is a trailing suffix, zero if not.
+  */
+int str_trailing_suffix(string_ty *haystack, string_ty *needle);
+
+/**
+  * The str_identifier function is used to generate another string,
+  * replaceing all non-C-identifier characters with underscore.  The
+  * intention is to generate a valid C identifier from the string.
+  *
+  * @param str
+  *     The string to be converted.
+  */
+string_ty *str_identifier(string_ty *str);
+
+/**
+  * The str_replace function may be used to alter a string by replacing
+  * one constant substring with another.
+  *
+  * @note
+  *     The replacement is <i>not</b> done <i>in situ</i>.  The original
+  *     \a str is unaltered.
+  *
+  * @param str
+  *     The string to be altered.
+  * @param lhs
+  *     The substring to look for within \a str
+  * @param rhs
+  *     The substring to replace \a lhs if found within \a str
+  * @param maximum
+  *     The maximum number of times to perform the replacement.
+  *     Defaults to "infinity".
+  * @returns
+  *     A new string with the replacements made.
+  */
+string_ty *str_replace(string_ty *str, string_ty *lhs, string_ty *rhs,
+    int maximum = -1);
+
+/** @} */
+
+#endif // STR_H
