@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1992, 1993, 2002 Peter Miller.
+ *	Copyright (C) 1992, 1993, 2002, 2003 Peter Miller.
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,11 +23,9 @@
 #ifndef PARSE_H
 #define PARSE_H
 
-#include <main.h>
+#include <nstring.h>
 
-struct string_ty;
-
-void generate_code__init(struct string_ty *);
-void parse(char *in, char *c_out, char *h_out);
+void generate_code__init(const nstring &);
+void parse(const char *in, const char *c_out, const char *h_out);
 
 #endif /* PARSE_H */
