@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-2003 Peter Miller;
+ *	Copyright (C) 1991-2005 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -40,6 +40,7 @@ enum
 	arglex_token_clean,
 	arglex_token_clone,
 	arglex_token_configured,
+	arglex_token_configured_not,
 	arglex_token_copy_file,
 	arglex_token_copy_file_undo,
 	arglex_token_current_relative,
@@ -59,6 +60,7 @@ enum
 	arglex_token_edit,
 	arglex_token_edit_bg,
 	arglex_token_file,
+	arglex_token_file_attributes,
 	arglex_token_fix_architecture,
 	arglex_token_force,
 	arglex_token_grandparent,
@@ -106,8 +108,6 @@ enum
 	arglex_token_pager_not,
 	arglex_token_page_headers,
 	arglex_token_page_headers_not,
-	arglex_token_page_length,
-	arglex_token_page_width,
 	arglex_token_persevere,
 	arglex_token_persevere_not,
 	arglex_token_progress,
@@ -134,7 +134,10 @@ enum
 	arglex_token_review_fail,
 	arglex_token_review_pass,
 	arglex_token_review_pass_undo,
+	arglex_token_signed_off_by,
+	arglex_token_signed_off_by_not,
 	arglex_token_suggest,
+	arglex_token_suggest_limit,
 	arglex_token_suggest_noise,
 	arglex_token_symbolic_links,
 	arglex_token_symbolic_links_not,
@@ -143,10 +146,13 @@ enum
 	arglex_token_template_not,
 	arglex_token_terse,
 	arglex_token_test,
+	arglex_token_touch,
+	arglex_token_touch_not,
 	arglex_token_trunk,
 	arglex_token_unchanged,
 	arglex_token_unformatted,
 	arglex_token_user,
+        arglex_token_uuid,
 	arglex_token_verbose,
 	arglex_token_wait,
 	arglex_token_wait_not,
