@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1999, 2002 Peter Miller;
+ *	Copyright (C) 1999, 2002, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,6 @@
 
 #include <cstate.h>
 
-void change_cstate_improve(cstate);
+void change_cstate_improve(cstate_ty *);
 
 #endif /* LIBAEGIS_CHANGE_CSTATE_IMPROVE_H */
