@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1993, 1994, 1999, 2002 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1999, 2002, 2004, 2005 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -31,14 +31,32 @@
 struct stat;
 struct utimbuf;
 struct flock;
+struct string_list_ty; /* forward */
 
-int copyfile(char *src, char *dst);
-int catfile(char *path);
-int read_whole_dir(char *path, char **data, long *datalen);
-int file_compare(char *, char *);
-int file_fingerprint(char *path, char *buf, int max);
-int rmdir_bg(char *path);
-int rmdir_tree(char *path);
+int copyfile(const char *src, const char *dst);
+int catfile(const char *path);
+int read_whole_dir(const char *path, char **data, long *datalen);
+
+/**
+  * The read_whole_dir__wl function may be used to read the list of file
+  * names contained in a directory.  It is returned as a string_list_ty.
+  * The string list is initialized (via string_list_constructor) before
+  * the results are appended.
+  */
+int read_whole_dir__wl(const char *path, struct string_list_ty *);
+
+/**
+  * The read_whole_dir__wla function may be used to read the list of
+  * file names contained in a directory and append them to the given
+  * string list.  It is returned as a string_list_ty.  The string list
+  * is NOT initialized first.
+  */
+int read_whole_dir__wla(const char *path, struct string_list_ty *);
+
+int file_compare(const char *, const char *);
+int file_fingerprint(const char *path, char *buf, int max);
+int rmdir_bg(const char *path);
+int rmdir_tree(const char *path);
 
 int glue_access(char *path, int mode);
 int glue_catfile(char *path);
@@ -64,11 +82,14 @@ int glue_open(char *path, int mode, int perm);
 long glue_pathconf(char *path, int mode);
 long glue_read(int fd, void *data, size_t len);
 int glue_readlink(char *path, char *buf, int max);
-int glue_read_whole_dir(char *path, char **data, long *datalen);
+int glue_read_whole_dir(const char *path, char **data, long *datalen);
 int glue_rename(char *p1, char *p2);
-int glue_rmdir(char *path);
-int glue_rmdir_bg(char *path);
-int glue_rmdir_tree(char *path);
+int glue_rmdir(const char *path);
+
+int glue_rmdir_bg(const char *path);
+
+int glue_rmdir_tree(const char *path);
+
 int glue_stat(char *path, struct stat *st);
 int glue_symlink(char *name1, char *name2);
 int glue_ungetc(int, FILE *);
@@ -90,7 +111,7 @@ int glue_fwrite(char *, long, long, FILE *);
 #define	glue_catfile	catfile
 #define	glue_chmod	chmod
 #define	glue_chown	chown
-#define	glue_close	close
+#define	glue_close	::close
 #define	glue_creat	creat
 #define	glue_copyfile	copyfile
 #define	glue_fclose	fclose
@@ -106,9 +127,9 @@ int glue_fwrite(char *, long, long, FILE *);
 #define	glue_link	link
 #define	glue_lstat	lstat
 #define	glue_mkdir	mkdir
-#define	glue_open	open
+#define	glue_open	::open
 #define	glue_pathconf	pathconf
-#define	glue_read	read
+#define	glue_read	::read
 #define	glue_readlink	readlink
 #define	glue_read_whole_dir	read_whole_dir
 #define	glue_rename	rename
@@ -120,7 +141,7 @@ int glue_fwrite(char *, long, long, FILE *);
 #define	glue_ungetc	ungetc
 #define	glue_unlink	unlink
 #define	glue_utime	utime
-#define	glue_write	write
+#define	glue_write	::write
 #define	glue_fwrite	fwrite
 
 #endif /* aegis_glue_disable */
