@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2002 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,7 @@
 
 #include <input.h>
 
-input_ty *input_crlf _((input_ty *, int));
+input_ty *input_crlf(input_ty *, int);
+void input_crlf_escaped_newline(input_ty *);
 
 #endif /* LIBAEGIS_INPUT_CRLF_H */
