@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-1996, 1999, 2002 Peter Miller;
+ *	Copyright (C) 1991-1996, 1999, 2002-2004 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,7 @@
 #include <ac/time.h>
 
 #include <main.h>
-#include <type.h>
+#include <meta_type.h>
 
 struct sub_context_ty; /* existence */
 struct output_ty; /* existence */
@@ -35,10 +35,16 @@ struct output_ty; /* existence */
 #define REAL_NOT_SET 0.0
 #define TIME_NOT_SET (time_t)0
 
+void boolean_write(struct output_ty *, const char *, bool, int);
+void boolean_write_xml(struct output_ty *, const char *, bool, int);
 void string_write(struct output_ty *, const char *, string_ty *);
+void string_write_xml(struct output_ty *, const char *, string_ty *);
 void integer_write(struct output_ty *, const char *, long, int);
+void integer_write_xml(struct output_ty *, const char *, long, int);
 void real_write(struct output_ty *, const char *, double, int);
+void real_write_xml(struct output_ty *, const char *, double, int);
 void time_write(struct output_ty *, const char *, time_t, int);
+void time_write_xml(struct output_ty *, const char *, time_t, int);
 void io_comment_append(struct sub_context_ty *, const char *);
 void io_comment_emit(struct output_ty *);
 
