@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1999, 2002 Peter Miller;
+ *	Copyright (C) 1999, 2002, 2003 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -26,8 +26,8 @@
 #include <main.h>
 
 struct project_ty; /* existence */
-struct pattr; /* existence */
+struct pattr_ty; /* existence */
 
-void project_pattr_get(struct project_ty *, struct pattr *);
+void project_pattr_get(struct project_ty *, struct pattr_ty *);
 
 #endif /* LIBAEGIS_PROJECT_PATTR_GET_H */
