@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1996-1998, 2000-2001 Peter Miller;
+#	Copyright (C) 1996-1998, 2000, 2001, 2004 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -87,6 +87,7 @@ check_it()
 		-e 's/20[0-9][0-9]/YYYY/' \
 		-e 's/node = ".*"/node = "NODE"/' \
 		-e 's/crypto = ".*"/crypto = "GUNK"/' \
+		-e 's/uuid = ".*"/uuid = "UUID"/' \
 		< $2 > $work/sed.out
 	if test $? -ne 0; then no_result; fi
 	diff $1 $work/sed.out
@@ -233,6 +234,7 @@ src =
 [
 	{
 		file_name = "c/d";
+		uuid = "UUID";
 		action = modify;
 		edit_origin =
 		{
@@ -243,6 +245,7 @@ src =
 	},
 	{
 		file_name = "c/e";
+		uuid = "UUID";
 		action = modify;
 		edit_origin =
 		{
