@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1996, 1997, 1998 Peter Miller;
+#	Copyright (C) 1996-1998, 2000, 2004 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -84,7 +84,7 @@ check_it()
 {
 	sed	-e "s|$work|...|g" \
 		-e 's|= [0-9][0-9]*; /.*|= TIME;|' \
-		-e "s/$USER/USER/g" \
+		-e "s/\"$USER\"/\"USER\"/g" \
 		-e 's/19[0-9][0-9]/YYYY/' \
 		-e 's/20[0-9][0-9]/YYYY/' \
 		-e 's/node = ".*"/node = "NODE"/' \
@@ -120,7 +120,7 @@ unset LANGUAGE
 # test the aentu directory functionality
 #
 activity="new project 124"
-$bin/aegis -npr $AEGIS_PROJECT -vers "" -v > log 2>&1
+$bin/aegis -npr $AEGIS_PROJECT -vers "" -v -dir $work/test > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 activity="project attributes 128"
@@ -189,7 +189,7 @@ src =
 	{
 		file_name = "config";
 		action = create;
-		usage = source;
+		usage = config;
 	},
 ];
 fubar
