@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1996-1998, 2000-2001 Peter Miller;
+#	Copyright (C) 1996-1998, 2000, 2001, 2004 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -89,6 +89,7 @@ check_it()
 		-e 's/20[0-9][0-9]/YYYY/' \
 		-e 's/node = ".*"/node = "NODE"/' \
 		-e 's/crypto = ".*"/crypto = "GUNK"/' \
+		-e 's/uuid = ".*"/uuid = "UUID"/' \
 		< $2 > $work/sed.out
 	if test $? -ne 0; then no_result; fi
 	diff $1 $work/sed.out
@@ -120,7 +121,7 @@ unset LANGUAGE
 # test the cross-branch merge functionality
 #
 activity="new project 124"
-$bin/aegis -npr $AEGIS_PROJECT -vers "" > log 2>&1
+$bin/aegis -npr $AEGIS_PROJECT -vers "" -dir $work/test > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 activity="project attributes 128"
@@ -367,6 +368,7 @@ src =
 [
 	{
 		file_name = "config";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -378,7 +380,7 @@ src =
 			revision = "1.1";
 			encoding = none;
 		};
-		usage = source;
+		usage = config;
 		file_fp =
 		{
 			youngest = TIME;
@@ -388,6 +390,7 @@ src =
 	},
 	{
 		file_name = "fred";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -418,6 +421,7 @@ src =
 [
 	{
 		file_name = "fred";
+		uuid = "UUID";
 		action = modify;
 		edit =
 		{
@@ -490,6 +494,7 @@ src =
 [
 	{
 		file_name = "fred";
+		uuid = "UUID";
 		action = modify;
 		edit_origin =
 		{
@@ -546,6 +551,7 @@ src =
 [
 	{
 		file_name = "fred";
+		uuid = "UUID";
 		action = modify;
 		edit =
 		{
