@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1997, 1998, 2000-2002 Peter Miller;
+#	Copyright (C) 1997, 1998, 2000-2002, 2004 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -302,6 +302,7 @@ check_it()
 		-e 's/20[0-9][0-9]/YYYY/' \
 		-e 's/node = ".*"/node = "NODE"/' \
 		-e 's/crypto = ".*"/crypto = "GUNK"/' \
+		-e 's/uuid = ".*"/uuid = "UUID"/' \
 		< $2 > $work/sed.out
 	if test $? -ne 0; then fail; fi
 	diff $1 $work/sed.out
@@ -313,6 +314,7 @@ src =
 [
 	{
 		file_name = "config";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -324,7 +326,7 @@ src =
 			revision = "1.1";
 			encoding = none;
 		};
-		usage = source;
+		usage = config;
 		file_fp =
 		{
 			youngest = TIME;
@@ -334,6 +336,7 @@ src =
 	},
 	{
 		file_name = "fred";
+		uuid = "UUID";
 		action = remove;
 		edit =
 		{
@@ -361,6 +364,7 @@ src =
 [
 	{
 		file_name = "fred";
+		uuid = "UUID";
 		action = transparent;
 		edit =
 		{
@@ -374,7 +378,6 @@ src =
 		};
 		usage = source;
 		locked_by = 10;
-		about_to_be_created_by = 10;
 		about_to_be_copied_by = 10;
 		deleted_by = 10;
 	},
@@ -415,10 +418,11 @@ src =
 [
 	{
 		file_name = "fred";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
-			revision = "1.2";
+			revision = "1.1";
 			encoding = none;
 		};
 		edit_origin =
