@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1997-1998, 2000-2001 Peter Miller;
+#	Copyright (C) 1997, 1998, 2000, 2001, 2004 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -87,6 +87,7 @@ check_it()
 		-e 's/20[0-9][0-9]/YYYY/' \
 		-e 's/node = ".*"/node = "NODE"/' \
 		-e 's/crypto = ".*"/crypto = "GUNK"/' \
+		-e 's/uuid = ".*"/uuid = "UUID"/' \
 		< $2 > $work/sed.out
 	if test $? -ne 0; then fail; fi
 	diff $1 $work/sed.out
@@ -309,6 +310,7 @@ src =
 [
 	{
 		file_name = "a.test.sh";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -343,6 +345,7 @@ src =
 	},
 	{
 		file_name = "config";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -354,7 +357,7 @@ src =
 			revision = "1.1";
 			encoding = none;
 		};
-		usage = source;
+		usage = config;
 		file_fp =
 		{
 			youngest = TIME;
@@ -370,6 +373,7 @@ src =
 	},
 	{
 		file_name = "fred";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -449,6 +453,7 @@ src =
 [
 	{
 		file_name = "a.test.sh";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -477,6 +482,7 @@ src =
 	},
 	{
 		file_name = "config";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -488,7 +494,7 @@ src =
 			revision = "1.2";
 			encoding = none;
 		};
-		usage = source;
+		usage = config;
 		file_fp =
 		{
 			youngest = TIME;
@@ -498,6 +504,7 @@ src =
 	},
 	{
 		file_name = "fred";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
