@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1998, 2000-2001 Peter Miller;
+#	Copyright (C) 1998, 2000, 2001, 2004 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -60,6 +60,7 @@ check_it()
 		-e 's/20[0-9][0-9]/YYYY/' \
 		-e 's/node = ".*"/node = "NODE"/' \
 		-e 's/crypto = ".*"/crypto = "GUNK"/' \
+		-e 's/uuid = ".*"/uuid = "UUID"/' \
 		< $2 > $work/sed.out
 	if test $? -ne 0; then no_result; fi
 	diff $1 $work/sed.out
@@ -119,7 +120,7 @@ export AEGIS_PATH
 # test the aecp -delta functionality
 #
 activity="new project 123"
-$bin/aegis -npr test -version 4.2 -v > log 2>&1
+$bin/aegis -npr test -version 4.2 -v -dir $work/test > log 2>&1
 if test $? -ne 0 ; then cat log; no_result; fi
 
 activity="project attributes 127"
@@ -303,16 +304,18 @@ src =
 [
 	{
 		file_name = "config";
+		uuid = "UUID";
 		action = modify;
 		edit_origin =
 		{
 			revision = "1.1";
 			encoding = none;
 		};
-		usage = source;
+		usage = config;
 	},
 	{
 		file_name = "fred";
+		uuid = "UUID";
 		action = modify;
 		edit_origin =
 		{
@@ -323,6 +326,7 @@ src =
 	},
 	{
 		file_name = "test/00/t0001a.sh";
+		uuid = "UUID";
 		action = modify;
 		edit_origin =
 		{
