@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 2001, 2002 Peter Miller;
+#	Copyright (C) 2001, 2002, 2004 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -86,6 +86,7 @@ check_it()
 		-e 's/20[0-9][0-9]/YYYY/' \
 		-e 's/node = ".*"/node = "NODE"/' \
 		-e 's/crypto = ".*"/crypto = "GUNK"/' \
+		-e 's/uuid = ".*"/uuid = "UUID"/' \
 		< $2 > $work/sed.out
 	if test $? -ne 0; then no_result; fi
 	diff $1 $work/sed.out
@@ -296,6 +297,7 @@ src =
 [
 	{
 		file_name = "config";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -307,7 +309,7 @@ src =
 			revision = "1.1";
 			encoding = none;
 		};
-		usage = source;
+		usage = config;
 		file_fp =
 		{
 			youngest = TIME;
@@ -323,6 +325,7 @@ src =
 	},
 	{
 		file_name = "fred";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -363,13 +366,15 @@ src =
 [
 	{
 		file_name = "config";
+		uuid = "UUID";
 		action = transparent;
-		usage = source;
+		usage = config;
 		locked_by = 1;
 		about_to_be_created_by = 1;
 	},
 	{
 		file_name = "fred";
+		uuid = "UUID";
 		action = transparent;
 		usage = source;
 		locked_by = 1;
