@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 2002 Peter Miller;
+#	Copyright (C) 2002, 2004 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -54,6 +54,7 @@ check_it()
 		-e 's/20[0-9][0-9]/YYYY/' \
 		-e 's/node = ".*"/node = "NODE"/' \
 		-e 's/crypto = ".*"/crypto = "GUNK"/' \
+		-e 's/uuid = ".*"/uuid = "UUID"/' \
 		< $2 > $work/sed.out
 	if test $? -ne 0; then no_result; fi
 	diff $1 $work/sed.out
@@ -406,6 +407,7 @@ src =
 [
 	{
 		file_name = "bogus";
+		uuid = "UUID";
 		action = transparent;
 		edit_origin =
 		{
@@ -528,6 +530,7 @@ src =
 [
 	{
 		file_name = "bogus";
+		uuid = "UUID";
 		action = transparent;
 		edit_origin =
 		{
@@ -567,6 +570,7 @@ src =
 [
 	{
 		file_name = "bogus";
+		uuid = "UUID";
 		action = transparent;
 		edit_origin =
 		{
@@ -648,6 +652,7 @@ src =
 [
 	{
 		file_name = "bogus";
+		uuid = "UUID";
 		action = modify;
 		edit =
 		{
@@ -721,6 +726,7 @@ src =
 [
 	{
 		file_name = "bogus";
+		uuid = "UUID";
 		action = transparent;
 		edit_origin =
 		{
@@ -755,6 +761,7 @@ state = completed;
 given_test_exemption = true;
 given_regression_test_exemption = true;
 delta_number = 2;
+delta_uuid = "UUID";
 minimum_integration = true;
 project_file_command_sync = 88;
 history =
@@ -790,6 +797,7 @@ history =
 		who = "USER";
 	},
 ];
+uuid = "UUID";
 end
 if test $? -ne 0 ; then no_result; fi
 
@@ -801,6 +809,7 @@ src =
 [
 	{
 		file_name = "bogus";
+		uuid = "UUID";
 		action = transparent;
 		edit =
 		{
@@ -840,6 +849,7 @@ src =
 [
 	{
 		file_name = "bogus";
+		uuid = "UUID";
 		action = transparent;
 		edit =
 		{
@@ -965,6 +975,7 @@ src =
 [
 	{
 		file_name = "bogus";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -986,6 +997,7 @@ src =
 	},
 	{
 		file_name = "config";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -997,7 +1009,7 @@ src =
 			revision = "1.1";
 			encoding = none;
 		};
-		usage = source;
+		usage = config;
 		file_fp =
 		{
 			youngest = TIME;
@@ -1045,6 +1057,7 @@ src =
 [
 	{
 		file_name = "bogus";
+		uuid = "UUID";
 		action = transparent;
 		edit =
 		{
@@ -1082,6 +1095,7 @@ copyright_years =
 ];
 state = completed;
 delta_number = 2;
+delta_uuid = "UUID";
 minimum_integration = true;
 history =
 [
@@ -1116,6 +1130,7 @@ history =
 		who = "USER";
 	},
 ];
+uuid = "UUID";
 branch =
 {
 	umask = 022;
@@ -1175,6 +1190,7 @@ src =
 [
 	{
 		file_name = "bogus";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -1190,6 +1206,7 @@ src =
 	},
 	{
 		file_name = "config";
+		uuid = "UUID";
 		action = create;
 		edit =
 		{
@@ -1201,7 +1218,7 @@ src =
 			revision = "1.1";
 			encoding = none;
 		};
-		usage = source;
+		usage = config;
 		file_fp =
 		{
 			youngest = TIME;
